@@ -1,14 +1,17 @@
 import os
+import sys
 import pickle
 import logging
 import argparse
 from pathlib import Path
 import pathos.multiprocessing as multiprocessing  # Better multiprocessing
 
+if 'XDG_DATA_HOME' in os.environ.keys():
+    rabies_path = os.environ['XDG_DATA_HOME']+'/rabies'
+else:
+    rabies_path = os.environ['HOME']+'/.local/share/rabies'
 
 def get_parser():
-    import rabies
-    dir_path = os.path.dirname(os.path.realpath(rabies.__file__))
 
     """Build parser object"""
     parser = argparse.ArgumentParser(
@@ -170,28 +173,28 @@ def get_parser():
     g_atlas = preprocess.add_argument_group(
         'Provided commonspace atlas files.')
     g_atlas.add_argument('--anat_template', action='store', type=Path,
-                         default="%s/../template_files/DSURQE_40micron_average.nii.gz" % (
-                             dir_path),
+                         default="%s/DSURQE_40micron_average.nii.gz" % (
+                             rabies_path),
                          help='Anatomical file for the commonspace template.')
     g_atlas.add_argument('--brain_mask', action='store', type=Path,
-                         default="%s/../template_files/DSURQE_100micron_mask.nii.gz" % (
-                             dir_path),
+                         default="%s/DSURQE_40micron_mask.nii.gz" % (
+                             rabies_path),
                          help='Brain mask for the template.')
     g_atlas.add_argument('--WM_mask', action='store', type=Path,
-                         default="%s/../template_files/DSURQE_100micron_eroded_WM_mask.nii.gz" % (
-                             dir_path),
+                         default="%s/DSURQE_40micron_eroded_WM_mask.nii.gz" % (
+                             rabies_path),
                          help='White matter mask for the template.')
     g_atlas.add_argument('--CSF_mask', action='store', type=Path,
-                         default="%s/../template_files/DSURQE_100micron_eroded_CSF_mask.nii.gz" % (
-                             dir_path),
+                         default="%s/DSURQE_40micron_eroded_CSF_mask.nii.gz" % (
+                             rabies_path),
                          help='CSF mask for the template.')
     g_atlas.add_argument('--vascular_mask', action='store', type=Path,
-                         default="%s/../template_files/vascular_mask.nii.gz" % (
-                             dir_path),
+                         default="%s/vascular_mask.nii.gz" % (
+                             rabies_path),
                          help='Can provide a mask of major blood vessels for computing confound timeseries. The default mask was generated by applying MELODIC ICA and selecting the resulting component mapping onto major veins. (Grandjean et al. 2020, NeuroImage; Beckmann et al. 2005)')
     g_atlas.add_argument('--labels', action='store', type=Path,
-                         default="%s/../template_files/DSURQE_40micron_labels.nii.gz" % (
-                             dir_path),
+                         default="%s/DSURQE_40micron_labels.nii.gz" % (
+                             rabies_path),
                          help='Atlas file with anatomical labels.')
 
     confound_regression.add_argument('preprocess_out', action='store', type=Path,
@@ -238,6 +241,9 @@ def get_parser():
                                      default=False,
                                      help="""Whether to remove timepoints that present outlier values on the DVARS metric (temporal derivative of global signal).
                                      This option will create a distribution of DVARS values which has no outlier values above or below 2.5 standard deviations.""")
+    confound_regression.add_argument('--minimum_timepoint', type=int,
+                                     default=3,
+                                     help='Can specify a minimal number of timepoint to remain in the timeseries after censoring, otherwise it returns empty files.')
     confound_regression.add_argument('--standardize', dest='standardize', action='store_true',
                                      default=False,
                                      help="""Whether to standardize timeseries to unit variance.""")
@@ -248,6 +254,9 @@ def get_parser():
                           help='path to RABIES confound regression output directory with the datasink.')
     analysis.add_argument('output_dir', action='store', type=Path,
                           help='the output path to drop analysis outputs.')
+    analysis.add_argument('--wf_name', type=str, default='analysis_wf',
+                                     help='Can specify a name for the workflow of this analysis run, to avoid potential '
+                                     'overlaps with previous runs.')
     analysis.add_argument('--scan_list', type=str,
                                      nargs="*",  # 0 or more values expected => creates a list
                                      default=['all'],
@@ -295,6 +304,9 @@ def get_parser():
                           help='path to RABIES confound regression output directory with the datasink.')
     data_diagnosis.add_argument('output_dir', action='store', type=Path,
                           help='the output path to drop data_diagnosis outputs.')
+    data_diagnosis.add_argument('--wf_name', type=str, default='data_diagnosis_wf',
+                                     help='Can specify a name for the workflow of this data diagnosis run, to avoid potential '
+                                     'overlaps with previous runs.')
     data_diagnosis.add_argument('--scan_list', type=str,
                                      nargs="*",  # 0 or more values expected => creates a list
                                      default=['all'],
@@ -304,14 +316,11 @@ def get_parser():
                                      "or the files can be imbedded into a .txt file with one filename per row."
                                      "By default, 'all' will use all the scans previously processed."
                                      )
-    data_diagnosis.add_argument('--dual_regression', dest='dual_regression', action='store_true',
-                                     default=False,
-                                     help="""Whether to evaluate dual regression outputs.""")
     data_diagnosis.add_argument('--dual_convergence', type=int, default=0,
                              help="Can specify a number of components to compute using a dual convergence framework.")
     data_diagnosis.add_argument('--prior_maps', action='store', type=Path,
-                          default="%s/../template_files/melodic_IC.nii.gz" % (
-                              dir_path),
+                          default="%s/melodic_IC.nii.gz" % (
+                              rabies_path),
                           help="Provide a 4D nifti image with a series of spatial priors representing common sources of signal (e.g. ICA components from a group-ICA run)."
                           "The default file corresponds to a MELODIC run on a combined group of anesthetized-ventilated mice with MEDISO and awake mice."
                           "Confound regression consisted of highpass at 0.01 Hz, FD censoring at 0.03mm, DVARS censoring, and mot_6,WM_signal,CSF_signal as regressors."
@@ -353,6 +362,14 @@ def execute_workflow():
                         format='%(asctime)s - %(levelname)s - %(message)s', level=os.environ.get("LOGLEVEL", "INFO"))
     log = logging.getLogger('root')
 
+    handler = logging.StreamHandler(sys.stdout)
+    formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
+    handler.setFormatter(formatter)
+    log.addHandler(handler)
+
+    # verify default template installation
+    install_DSURQE(log)
+
     from .__version__ import __version__
     log.info('Running RABIES - version: '+__version__)
 
@@ -376,7 +393,7 @@ def execute_workflow():
         parser.print_help()
 
     try:
-        print('Running workflow with %s plugin.' % opts.plugin)
+        log.info('Running workflow with %s plugin.' % opts.plugin)
         # execute workflow, with plugin_args limiting the cluster load for parallel execution
         workflow.run(plugin=opts.plugin, plugin_args={'max_jobs': 50, 'dont_resubmit_completed_jobs': True,
                                                       'n_procs': opts.local_threads, 'qsub_args': '-pe smp %s' % (str(opts.min_proc))})
@@ -394,10 +411,7 @@ def preprocess(opts, cr_opts, analysis_opts, data_diagnosis_opts, log):
         raise ValueError("The provided BIDS data path doesn't exists.")
     else:
         # print the input data directory tree
-        from rabies.preprocess_pkg.utils import run_command
-        print("INPUT BIDS DATASET: ")
-        log.info("INPUT BIDS DATASET: ")
-        rc = run_command('tree %s' % (data_dir_path), verbose = True)
+        log.info("INPUT BIDS DATASET:  \n" + list_files(data_dir_path))
 
     import SimpleITK as sitk
     if str(opts.data_type) == 'int16':
@@ -464,7 +478,7 @@ def preprocess(opts, cr_opts, analysis_opts, data_diagnosis_opts, log):
                                       'filemanip_level': 'DEBUG',
                                       'interface_level': 'DEBUG',
                                       'utils_level': 'DEBUG'}
-        print('Debug ON')
+        log.debug('Debug ON')
 
     return workflow
 
@@ -502,3 +516,39 @@ def data_diagnosis(opts, log):
     workflow = confound_regression(confound_regression_opts, None, opts, log)
 
     return workflow
+
+
+def install_DSURQE(log):
+
+    install=False
+    # verifies whether default template files are installed and installs them otherwise
+    if not os.path.isfile("%s/DSURQE_40micron_average.nii.gz" % (rabies_path)):
+        install=True
+    elif not os.path.isfile("%s/DSURQE_40micron_mask.nii.gz" % (rabies_path)):
+        install=True
+    elif not os.path.isfile("%s/DSURQE_40micron_eroded_WM_mask.nii.gz" % (rabies_path)):
+        install=True
+    elif not os.path.isfile("%s/DSURQE_40micron_eroded_CSF_mask.nii.gz" % (rabies_path)):
+        install=True
+    elif not os.path.isfile("%s/DSURQE_40micron_labels.nii.gz" % (rabies_path)):
+        install=True
+    elif not os.path.isfile("%s/vascular_mask.nii.gz" % (rabies_path)):
+        install=True
+    elif not os.path.isfile("%s/melodic_IC.nii.gz" % (rabies_path)):
+        install=True
+    if install:
+        from rabies.preprocess_pkg.utils import run_command
+        log.info("SOME FILES FROM THE DEFAULT TEMPLATE ARE MISSING. THEY WILL BE INSTALLED BEFORE FURTHER PROCESSING.")
+        rc = run_command('install_DSURQE.sh %s' % (rabies_path), verbose = True)
+
+
+def list_files(startpath):
+    string = ''
+    for root, dirs, files in os.walk(startpath):
+        level = root.replace(startpath, '').count(os.sep)
+        indent = ' ' * 4 * (level)
+        string+='{}{}/ \n'.format(indent, os.path.basename(root))
+        subindent = ' ' * 4 * (level + 1)
+        for f in files:
+            string+='{}{} \n'.format(subindent, f)
+    return string
